package com.inoct.NoctuAuthenticator.controller;

import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.annotation.AuthenticationPrincipal;
import org.springframework.security.oauth2.core.user.OAuth2User;
import org.springframework.web.bind.annotation.*;

import com.inoct.NoctuAuthenticator.dto.UserDTO;
import com.inoct.NoctuAuthenticator.entity.User;
import com.inoct.NoctuAuthenticator.service.UserService;


@RestController
@RequestMapping("/")
public class UserController {

    @Autowired
    private UserService userService;

    @GetMapping("/login")
    public ResponseEntity<UserDTO> loginUser(@RequestBody String username, @RequestBody String password) {
        UserDTO user = userService.authenticateUser(username, password);
        return user != null ? ResponseEntity.ok(user) : ResponseEntity.notFound().build();
    }

    @GetMapping("/oauth")
    public ResponseEntity<UserDTO> oauthLogin(@RequestBody String username, @RequestBody String password) {
        UserDTO user = userService.authenticateUser(username, password);
        return user != null ? ResponseEntity.ok(user) : ResponseEntity.notFound().build();
    }

    @PostMapping("/register")
    public ResponseEntity<User> registerUser(@RequestBody UserDTO userDTO) {
        System.out.println(userDTO);
        User user = userService.createUser(userDTO);
        return user != null ? ResponseEntity.ok(user) : ResponseEntity.notFound().build();
    }

    @PutMapping("/{id}")
    public ResponseEntity<UserDTO> updateUser(@PathVariable Long id, @RequestBody User userDetails) {
        UserDTO updatedUser = userService.updateUser(id, userDetails);
        return updatedUser != null ? ResponseEntity.ok(updatedUser) : ResponseEntity.notFound().build();
    }

    @DeleteMapping("/{id}")
    public ResponseEntity<Void> deleteUser(@PathVariable Long id) {
        userService.deleteUser(id);
        return ResponseEntity.noContent().build();
    }

    @GetMapping("/welcome")
    public String welcome(@AuthenticationPrincipal OAuth2User user) {
        Map<String, Object> attributes = user.getAttributes();
        return "Welcome " + attributes.get("name") + "!";
    }
}