package com.inoct.NoctuAuthenticator.entity;


import java.time.LocalDate;

import org.hibernate.annotations.UpdateTimestamp;
import org.hibernate.validator.constraints.UniqueElements;
import org.springframework.data.annotation.CreatedDate;

import com.inoct.NoctuAuthenticator.validation.ValidateUser;

import java.util.List;
import java.util.UUID;

import jakarta.persistence.*;
import jakarta.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.EqualsAndHashCode.Include;



@Entity
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Getter
@Setter
@ValidateUser
@Table(name = "users", 
uniqueConstraints = {
    @UniqueConstraint(columnNames = "username"),
    @UniqueConstraint(columnNames = "email")
})
@EqualsAndHashCode(onlyExplicitlyIncluded = true)
public class User {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Include
    private Long id;

    @Include
    @NotNull
    private String username;

    @Transient
    @Include
    private final UUID tempId = UUID.randomUUID();

    @NotNull
    private String firstName;
    @NotNull
    private String lastName;

    @Include
    private String email;

    private String password;

    private List<String> roles;

    @OneToOne(cascade = CascadeType.ALL, fetch = FetchType.LAZY)
    OauthData oauthData;

    @NotNull
    private boolean oauth;

    @CreatedDate
    @Column(updatable = false)
    private LocalDate createdDate;

    @UpdateTimestamp
    private LocalDate updatedDate;

}
