package com.inoct.NoctuAuthenticator.validation;

import com.inoct.NoctuAuthenticator.entity.User;
import jakarta.validation.ConstraintValidator;
import jakarta.validation.ConstraintValidatorContext;

public class ValidateUserValidator implements ConstraintValidator<ValidateUser, User> {

    @Override
    public boolean isValid(User user, ConstraintValidatorContext context) {
        if (user == null) {
            return true; // Validation for null objects is handled separately
        }

        // Example validation logic:
        // Ensure the username is not null and at least 3 characters long
        if (user.getUsername() == null || user.getUsername().length() < 3) {
            context.buildConstraintViolationWithTemplate("Username must be at least 3 characters long")
                   .addPropertyNode("username")
                   .addConstraintViolation();
            return false;
        }

        // Ensure the email follows a specific pattern (simplified example)
        if (user.getEmail() != null && !user.getEmail().contains("@")) {
            context.buildConstraintViolationWithTemplate("Invalid email format")
                   .addPropertyNode("email")
                   .addConstraintViolation();
            return false;
        }

        return true; // Valid user
    }
}
